/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Initial Developer of this code is David Baum.
 * Portions created by David Baum are Copyright (C) 1998 David Baum.
 * All Rights Reserved.
 */

#include <SerialPort.h>
#include "PSerial.h"

class PSerial_beos : public PSerial
{
public:
	virtual	bool	Open(const char *name);

	virtual void	Close();
	virtual long	Read(void *ptr, long count);
	virtual long	Write(const void *ptr, long count);
	virtual void	FlushWrite();

	virtual bool	SetTimeout(long timeout_ms);

	virtual bool	SetDTR(bool assert);
	virtual bool	SetRTS(bool assert);

	virtual bool	SetSpeed(int, int = 0) { return false; };	

private:
	BSerialPort serialport;
};


PSerial * PSerial::NewSerial()
{
	return new PSerial_beos();
}


const char *PSerial::GetDefaultName()
{
	return "/dev/ports/serial1";
}

bool PSerial_beos::Open(const char *name)
{
	if (serialport.Open(name) > 0){
		serialport.SetDataRate(B_2400_BPS);
		serialport.SetDataBits(B_DATA_BITS_8);
		serialport.SetStopBits(B_STOP_BITS_1);
		serialport.SetParityMode(B_ODD_PARITY);
		return true;
	} else
		return false;
}


bool PSerial_beos::SetTimeout(long timeout_ms)
{
	if(serialport.SetTimeout((bigtime_t) timeout_ms) == B_OK)
		return true;
	else
		return false;
}


void PSerial_beos::Close()
{
	serialport.Close();
}


long PSerial_beos::Write(const void *ptr, long count)
{
	return (long) serialport.Write(ptr, (size_t)count);
}


long PSerial_beos::Read(void *ptr, long count)
{
	return (long) serialport.Read(ptr, (size_t)count);
}


bool PSerial_beos::SetDTR(bool assert)
{
	return (serialport.SetDTR(assert) == B_OK);
}


bool PSerial_beos::SetRTS(bool assert)
{
	return (serialport.SetRTS(assert) == B_OK);
}


void PSerial_beos::FlushWrite()
{
	serialport.ClearInput();
}
